Identifying the context in which the affected page displays a Private
IP address is necessary.

If the page is publicly accessible and displays the Private IP of the
affected server (or supporting infrastructure), then measures should
be put in place to ensure that the IP address is removed from any response.